@@ -82,10 +82,13 @@ def is_logged_in(env, aws_region=None, allowed_commands=None):
     try:
         res = build_execute_command(command="whoami", aws_region=aws_region, allowed_commands=_allowed_commands)
 
-        if _err := res.get("error"):
+        if _err := res.get("err"):
             raise NotLoggedInOrWrongEnvError(f"Failed to execute 'rosa whoami': {_err}")
 
-        logged_in_ocm_env = res.get("out", {}).get("OCM API")
+        if not isinstance(res["out"], dict):
+            raise NotLoggedInOrWrongEnvError(f"Rosa `out` is not a dict': {res['out']}")
+
+        logged_in_ocm_env = res["out"].get("OCM API")
         if logged_in_ocm_env != env:
             raise NotLoggedInOrWrongEnvError(
                 f"User is logged in to OCM in {logged_in_ocm_env} environment and not {env} environment."
